==> kotlin-compiler-0.5.1131-sources.jar: org/jetbrains/jet/lang/diagnostics/rendering/DispatchingDiagnosticRenderer.java <==
/*
 * Copyright 2010-2013 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jetbrains.jet.lang.diagnostics.rendering;

import org.jetbrains.annotations.NotNull;
import org.jetbrains.jet.lang.diagnostics.Diagnostic;

public class DispatchingDiagnosticRenderer implements DiagnosticRenderer<Diagnostic> {
    private final DiagnosticFactoryToRendererMap[] maps;

    public DispatchingDiagnosticRenderer(DiagnosticFactoryToRendererMap... maps) {
        this.maps = maps;
    }

    @NotNull
    @Override
    public String render(@NotNull Diagnostic diagnostic) {
        for (DiagnosticFactoryToRendererMap map : maps) {
            DiagnosticRenderer renderer = map.get(diagnostic.getFactory());
            if (renderer != null) {
                //noinspection unchecked
                return renderer.render(diagnostic);
            }
        }
        throw new IllegalArgumentException("Don't know how to render diagnostic of type " + diagnostic.getFactory().getName());
    }
}

==> kotlin-compiler-0.9.976-sources.jar: org/jetbrains/jet/lang/diagnostics/rendering/DispatchingDiagnosticRenderer.java <==
/*
 * Copyright 2010-2013 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jetbrains.jet.lang.diagnostics.rendering;

import org.jetbrains.annotations.NotNull;
import org.jetbrains.jet.lang.diagnostics.Diagnostic;

import java.util.List;

public class DispatchingDiagnosticRenderer implements DiagnosticRenderer<Diagnostic> {
    private final List<DiagnosticFactoryToRendererMap> maps;

    public DispatchingDiagnosticRenderer(List<DiagnosticFactoryToRendererMap> maps) {
        this.maps = maps;
    }

    @NotNull
    @Override
    public String render(@NotNull Diagnostic diagnostic) {
        for (DiagnosticFactoryToRendererMap map : maps) {
            DiagnosticRenderer renderer = map.get(diagnostic.getFactory());
            if (renderer != null) {
                //noinspection unchecked
                return renderer.render(diagnostic);
            }
        }
        throw new IllegalArgumentException("Don't know how to render diagnostic of type " + diagnostic.getFactory().getName());
    }
}
